@@ -1,3 +1,5 @@
+use more_asserts::assert_ge;
+
 use crate::bindings::kernel;
 use crate::{cal_block_count, RgbaSurface};
 
@@ -16,7 +18,7 @@ pub fn compress_blocks(surface: &RgbaSurface) -> Vec<u8> {
 }
 
 pub fn compress_blocks_into(surface: &RgbaSurface, blocks: &mut [u8]) {
-    assert_eq!(
+    assert_ge!(
         blocks.len(),
         calc_output_size(surface.width, surface.height)
     );
